;; Generated package description from shell-quasiquote.el  -*- no-byte-compile: t -*-
(define-package "shell-quasiquote" "0.0.20201201.221117" "Turn s-expressions into shell command strings." 'nil :url "https://elpa.gnu.org/packages/shell-quasiquote.html" :keywords '("extensions" "unix") :authors '(("Taylan Ulrich Bayırlı/Kammer" . "taylanbayirli@gmail.com")) :maintainer '("Taylan Ulrich Bayırlı/Kammer" . "taylanbayirli@gmail.com"))
